@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1998 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1998-2000 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: DummyProto.h,v 1.2 1999/02/23 15:06:30 lav Exp $ */
+/* $Id: DummyProto.h,v 1.6 2000/04/20 16:45:50 lav Exp $ */
 
 #ifndef DUMMYPROTO_H
 #define DUMMYPROTO_H
@@ -35,7 +35,29 @@ public:
    int Read(void *buf,int size);
    int Write(const void *buf,int size);
    int StoreStatus();
-   void Reconfig() {}
+   void Reconfig(const char *) {}
+
+   DirList *MakeDirList(ArgV *);
+};
+
+class DummyNoProto : public FileAccess
+{
+   char *proto;
+public:
+   DummyNoProto(const char *p);
+   ~DummyNoProto();
+
+   int Do();
+   int Done();
+   const char *GetProto();
+   FileAccess *Clone();
+   int Read(void *buf,int size);
+   int Write(const void *buf,int size);
+   int StoreStatus();
+   void Reconfig(const char *) {}
+   const char *StrError(int err);
+
+   DirList *MakeDirList(ArgV *);
 };
 
 #endif
