@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Filter.h,v 1.8 2000/02/12 10:12:53 lav Exp $ */
+/* $Id: Filter.h,v 1.11 2000/07/28 17:02:25 lav Exp $ */
 
 #ifndef FILTER_H
 #define FILTER_H
@@ -44,7 +44,7 @@ public:
 
    void MakeErrorText();
 
-   virtual long getsize_and_seek_end();
+   virtual off_t get_size() { return -1; }
    virtual void setmtime(time_t) {}
    virtual bool can_setmtime() { return false; }
    virtual void remove_if_empty() {}
@@ -63,6 +63,7 @@ class OutputFilter : public FDStream
    ProcWait *w;
    pid_t pg;
    FDStream *second;
+   bool stderr_to_stdout;
 
    char *oldcwd;
 
@@ -84,8 +85,7 @@ public:
    virtual ~OutputFilter();
 
    void SetCwd(const char *);
-
-   long getsize_and_seek_end() { return 0; }
+   void StderrToStdout() { stderr_to_stdout=true; }
 
    int getfd();
    bool Done();
@@ -126,6 +126,7 @@ public:
    void remove();
    int getfd();
    bool can_seek();
+   off_t get_size();
 };
 
 #endif /* FILTER_H */
