@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FindJob.cc,v 1.13 2000/03/24 18:53:23 lav Exp $ */
+/* $Id: FindJob.cc,v 1.16 2000/07/30 15:54:31 lav Exp $ */
 
 #include <config.h>
 
@@ -33,6 +33,7 @@ int FinderJob::Do()
    int m=STALL;
    int res;
    prf_res pres;
+   Job *j;
 
    switch(state)
    {
@@ -159,10 +160,11 @@ int FinderJob::Do()
       return MOVED;
 
    case WAIT:
-      if(!waiting->Done())
+      j=FindDoneAwaitedJob();
+      if(!j)
 	 return m;
-      Delete(waiting);
-      waiting=0;
+      RemoveWaiting(j);
+      Delete(j);
       state=LOOP;
       m=MOVED;
       goto post_WAIT;
@@ -298,7 +300,7 @@ void FinderJob::ShowRunStatus(StatusLine *sl)
 			   session->CurrentStatus());
       break;
    case WAIT:
-      waiting->ShowRunStatus(sl);
+      Job::ShowRunStatus(sl);
       break;
    default:
       sl->Clear();
@@ -352,7 +354,7 @@ FinderJob_List::FinderJob_List(FileAccess *s,const char *d,FDStream *o)
    : FinderJob(s,d)
 {
    show_sl = !o->usesfd(1);
-   buf=new FileOutputBuffer(o);
+   buf=new IOBufferFDStream(o,IOBuffer::PUT);
 }
 
 FinderJob_List::~FinderJob_List()
@@ -416,7 +418,7 @@ FinderJob::prf_res FinderJob_Cmd::ProcessFile(const char *d,const FileInfo *f)
 #endif
       break;
    }
-   waiting=exec;
+   AddWaiting(exec);
    return PRF_WAIT;
 
 #undef ISDIR
@@ -428,6 +430,7 @@ FinderJob_Cmd::FinderJob_Cmd(FileAccess *s,ArgV *a,cmd_t c)
 {
    cmd=c;
    args=a;
+   op=args->a0();
    use_cache=false;
    if(cmd==RM)
       depth_first=true;
@@ -438,11 +441,13 @@ FinderJob_Cmd::~FinderJob_Cmd()
 {
    xfree(saved_cwd);
    delete args;
-   if(waiting)
+   while(waiting_num>0)
    {
-      if(waiting->waiting)
-	 waiting->waiting->jobno=-1; // prevent reparenting
-      Delete(waiting);
+      Job *r=waiting[0];
+      for(int k=0; k<r->waiting_num; k++)
+	 r->waiting[k]->jobno=-1; // prevent reparenting
+      RemoveWaiting(r);
+      Delete(r);
    }
 }
 
@@ -464,7 +469,7 @@ void FinderJob_Cmd::Finish()
 	 exec->FeedCmd("-- ");
 	 exec->FeedQuoted(start_dir);
 	 exec->FeedCmd("\n");
-	 waiting=exec;
+	 AddWaiting(exec);
 	 removing_last=true;
 	 state=WAIT; // it will wait for termination, try to process
 		     // next file and call Finish() again
