@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FtpListInfo.cc,v 1.27 2000/03/18 23:46:15 lav Exp $ */
+/* $Id: FtpListInfo.cc,v 1.30 2000/07/17 22:53:39 lav Exp $ */
 
 #include <config.h>
 #include "FtpListInfo.h"
@@ -57,7 +57,7 @@ int FtpListInfo::Do()
    FileInfo *file;
    int res;
    int m=STALL;
-   char	**slist_res;
+   FileSet *slist_res;
    int err;
 
    if(done)
@@ -84,8 +84,8 @@ int FtpListInfo::Do()
       slist_res=slist->GetResult();
 
       // don't consider empty list to be valid
-      if(slist_res && slist_res[0])
-	 result=ParseFtpLongList(slist_res,&err);
+      if(slist_res->get_fnum()>0)
+	 result=ParseFtpLongList(*slist_res,&err);
       else
 	 err=1;
 
@@ -227,7 +227,8 @@ const char *FtpListInfo::Status()
    case(GETTING_SHORT_LIST):
       if(!slist)
 	 return "";
-      sprintf(s,_("Getting directory contents (%ld)"),session->GetPos());
+      sprintf(s,_("Getting directory contents (%lld)"),
+		     (long long)session->GetPos());
       if(slist->RateValid())
 	 sprintf(s+strlen(s)," %s",slist->GetRateStr());
       status=session->CurrentStatus();
@@ -453,13 +454,13 @@ FileInfo *ParseFtpLongList_NT(const char *line_c,int *err)
    tms.tm_isdst=0;
    fi.SetDateUnprec(mktime(&tms));
 
-   unsigned long size;
+   long long size;
    if(!strcmp(t,"<DIR>"))
       fi.SetType(fi.DIRECTORY);
    else
    {
       fi.SetType(fi.NORMAL);
-      if(sscanf(t,"%lu",&size)!=1)
+      if(sscanf(t,"%lld",&size)!=1)
 	 ERR;
       fi.SetSize(size);
    }
@@ -502,9 +503,10 @@ FileInfo *ParseFtpLongList_EPLF(const char *line,int *err)
 
    const char *name=0;
    int name_len=0;
-   long size=NO_SIZE;
+   off_t size=NO_SIZE;
    time_t date=NO_DATE;
    long date_l;
+   long long size_ll;
    bool dir=false;
    bool type_known=false;
    int perms=-1;
@@ -521,7 +523,9 @@ FileInfo *ParseFtpLongList_EPLF(const char *line,int *err)
 	    scan=0;
 	    break;
 	 case 's':
-	    sscanf(scan+1,"%ld",&size);
+	    if(1 != sscanf(scan+1,"%lld",&size_ll))
+	       break;
+	    size = size_ll;
 	    break;
 	 case 'm':
 	    if(1 != sscanf(scan+1,"%ld",&date_l))
@@ -598,8 +602,8 @@ FileInfo *ParseFtpLongList_OS2(const char *line_c,int *err)
 
    FileInfo fi;
 
-   unsigned long size;
-   if(sscanf(t,"%lu",&size)!=1)
+   long long size;
+   if(sscanf(t,"%lld",&size)!=1)
       ERR;
    fi.SetSize(size);
 
@@ -660,11 +664,8 @@ static ListParser list_parsers[]={
    0
 };
 
-FileSet *FtpListInfo::ParseFtpLongList(const char * const *lines_c,int *err_ret)
+FileSet *FtpListInfo::ParseFtpLongList(const FileSet &lines,int *err_ret)
 {
-   if(lines_c==0)
-      return new FileSet;
-
    FileSet *result;
    int err;
    FileSet *best_result=0;
@@ -673,14 +674,11 @@ FileSet *FtpListInfo::ParseFtpLongList(const char * const *lines_c,int *err_ret)
    for(ListParser *parser=list_parsers; *parser; parser++)
    {
       err=0;
-
-      const char *line;
-      const char * const *lines = lines_c;
       result=new FileSet;
 
-      while((line=*lines++)!=0)
+      for(int i=0; lines[i]; i++)
       {
-	 FileInfo *fi=(*parser)(line,&err);
+	 FileInfo *fi=(*parser)(lines[i]->name,&err);
 	 if(fi)
 	 {
 	    if(!strchr(fi->name,'/'))
