@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: GetJob.cc,v 1.14 2000/03/22 15:24:00 lav Exp $ */
+/* $Id: GetJob.cc,v 1.18 2000/09/07 15:20:32 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -33,10 +33,13 @@
 #include "ArgV.h"
 #include "url.h"
 
-ResDecl res_clobber("xfer:clobber","yes",ResMgr::BoolValidate,0);
+ResDecl res_clobber	("xfer:clobber",     "yes",ResMgr::BoolValidate,ResMgr::NoClosure);
+ResDecl res_make_backup	("xfer:make-backup", "yes",ResMgr::BoolValidate,ResMgr::NoClosure);
 
 #define super CopyJobEnv
 
+#define NO_MODE ((mode_t)-1)
+
 int   GetJob::Do()
 {
    int m=STALL;
@@ -45,6 +48,8 @@ int   GetJob::Do()
    {
       // now we can delete old file, since there is new one
       RemoveBackupFile();
+      if(file_mode!=NO_MODE && local)
+	 chmod(local->full_name,file_mode);
    }
    if(super::Do()==MOVED)
       m=MOVED;
@@ -74,7 +79,7 @@ FileCopyPeer *GetJob::NoProtoDst(const char *dst)
 
    int flags=O_WRONLY|O_CREAT|(cont?0:O_TRUNC);
    const char *f=(cwd && dst[0]!='/') ? dir_file(cwd,dst) : dst;
-   if(!cont)
+   if(!cont && (bool)res_make_backup.Query(0))
    {
       /* rename old file if exists and size>0 */
       struct stat st;
@@ -89,14 +94,17 @@ FileCopyPeer *GetJob::NoProtoDst(const char *dst)
 	       count++;
 	       return 0;
 	    }
-	    backup_file=(char*)xmalloc(strlen(f)+2);
-	    strcpy(backup_file,f);
+	    backup_file=xstrdup(f,+1);
 	    strcat(backup_file,"~");
 	    if(rename(f,backup_file)!=0)
 	    {
 	       xfree(backup_file);
 	       backup_file=0;
 	    }
+	    else
+	    {
+	       file_mode=st.st_mode;
+	    }
 	 }
       }
    }
@@ -109,6 +117,7 @@ FileCopyPeer *GetJob::NoProtoDst(const char *dst)
 void GetJob::NextFile()
 {
 try_next:
+   file_mode=NO_MODE;
    if(backup_file)
    {
       xfree(backup_file);
@@ -173,6 +182,7 @@ GetJob::GetJob(FileAccess *s,ArgV *a,bool c)
 {
    delete_files=false;
    backup_file=0;
+   file_mode=NO_MODE;
    local=0;
    reverse=false;
 }
