@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Http.cc,v 1.109 2000/10/04 08:10:39 lav Exp $ */
+/* $Id: Http.cc,v 1.117 2001/02/13 16:50:21 lav Exp $ */
 
 #include <config.h>
 #include <unistd.h>
@@ -63,6 +63,7 @@ static void base64_encode (const char *s, char *store, int length);
 #define H_PARTIAL(x)    ((x) == 206)
 #define H_REDIRECTED(x) (((x) == 301) || ((x) == 302))
 #define H_EMPTY(x)	(((x) == 204) || ((x) == 205))
+#define H_CONTINUE(x)	((x) == 100)
 
 
 void Http::Init()
@@ -273,8 +274,13 @@ void Http::Send(const char *format,...)
 
 void Http::SendMethod(const char *method,const char *efile)
 {
-   char *ehost=string_alloca(strlen(hostname)*3+1);
-   url::encode_string(hostname,ehost);
+   char *ehost=string_alloca(strlen(hostname)*3+1+xstrlen(portname)*3+1);
+   url::encode_string(hostname,ehost,URL_HOST_UNSAFE);
+   if(portname)
+   {
+      strcat(ehost,":");
+      url::encode_string(portname,ehost+strlen(ehost),URL_PORT_UNSAFE);
+   }
    if(!use_head && !strcmp(method,"HEAD"))
       method="GET";
    last_method=method;
@@ -288,6 +294,7 @@ void Http::SendMethod(const char *method,const char *efile)
    }
 
    if(hftp && mode!=LONG_LIST && mode!=CHANGE_DIR && mode!=MAKE_DIR
+   && mode!=REMOVE && mode!=REMOVE_DIR
    && (strlen(efile)<7 || strncmp(efile+strlen(efile)-7,";type=",6)))
    {
       char *pfile=alloca_strdup2(efile,7);
@@ -328,7 +335,7 @@ void Http::SendAuth()
 {
    if(proxy && proxy_user && proxy_pass)
       SendBasicAuth("Proxy-Authorization",proxy_user,proxy_pass);
-   if(user && pass)
+   if(user && pass && !(hftp && !(bool)Query("use-authorization",proxy)))
       SendBasicAuth("Authorization",user,pass);
 }
 
@@ -379,6 +386,11 @@ void Http::SendRequest(const char *connection,const char *f)
 	 {
 	    strcpy(pfile,"ftp://");
 	    url::encode_string(user,pfile+strlen(pfile),URL_USER_UNSAFE);
+	    if(!(bool)Query("use-authorization",proxy))
+	    {
+	       strcat(pfile,":");
+	       url::encode_string(pass,pfile+strlen(pfile),URL_PASS_UNSAFE);
+	    }
 	    strcat(pfile,"@");
 	    url::encode_string(hostname,pfile+strlen(pfile),URL_HOST_UNSAFE);
 	    goto add_path;
@@ -962,7 +974,7 @@ int Http::Do()
       if(mode==STORE)
       {
 	 assert(rate_limit==0);
-	 rate_limit=new RateLimit();
+	 rate_limit=new RateLimit(hostname);
       }
 
    case RECEIVING_HEADER:
@@ -1030,14 +1042,21 @@ int Http::Do()
 	       }
 	       else if(mode==STORE)
 	       {
-		  if(sent_eot && H_20X(status_code))
+		  if(H_CONTINUE(status_code))
+		  {
+		     xfree(status);
+		     status=0;
+		     status_code=0;
+		     return MOVED;
+		  }
+		  if((sent_eot || pos==entity_size) && H_20X(status_code))
 		  {
 		     state=DONE;
 		     Disconnect();
 		     state=DONE;
 		     return MOVED;
 		  }
-		  if(!sent_eot && H_20X(status_code))
+		  if(H_20X(status_code))
 		  {
 		     // should never happen
 		     DebugPrint("**** ",_("Success, but did nothing??"),0);
@@ -1082,12 +1101,8 @@ int Http::Do()
 	       proto_version=(ver_major<<4)+ver_minor;
 	       if(!H_20X(status_code))
 	       {
-		  if(status_code==100)
-		  {
-		     // 100 Continue
-		     status_code=0;
-		     xfree(status);
-		  }
+		  if(H_CONTINUE(status_code))
+		     return MOVED;
 
 		  if(status_code/100==5) // server failed, try another
 		     NextPeer();
@@ -1123,7 +1138,7 @@ int Http::Do()
 	 }
       }
 
-      if(mode==STORE && !status && !sent_eot)
+      if(mode==STORE && (!status || H_CONTINUE(status_code)) && !sent_eot)
 	 Block(sock,POLLOUT);
 
       return m;
@@ -1174,7 +1189,7 @@ int Http::Do()
 
       DebugPrint("---- ",_("Receiving body..."));
       assert(rate_limit==0);
-      rate_limit=new RateLimit();
+      rate_limit=new RateLimit(hostname);
       if(real_pos<0) // assume Range: did not work
       {
 	 if(mode!=STORE && body_size>=0)
@@ -1301,6 +1316,7 @@ int Http::Read(void *buf,int size)
    get_again:
       if(recv_buf->Size()==0 && recv_buf->Error())
       {
+	 DebugPrint("**** ",recv_buf->ErrorText(),0);
 	 Disconnect();
 	 return DO_AGAIN;
       }
@@ -1456,7 +1472,7 @@ int Http::Write(const void *buf,int size)
    int res=write(sock,buf,size);
    if(res==-1)
    {
-      if(errno==EAGAIN || errno==EINTR)
+      if(E_RETRY(errno))
 	 return DO_AGAIN;
       if(NotSerious(errno) || errno==EPIPE)
       {
@@ -1539,7 +1555,7 @@ void Http::Reconfig(const char *name)
    super::Reconfig(name);
 
    no_cache = !(bool)Query("cache",c);
-   if(!hftp && NoProxy())
+   if(!hftp && NoProxy(hostname))
       SetProxy(0);
    else
    {
@@ -1855,22 +1871,6 @@ void HFtp::Reconfig(const char *name)
    use_head=Query("use-head");
 }
 
-/* Converts struct tm to time_t, assuming the data in tm is UTC rather
-   than local timezone (mktime assumes the latter).
-
-   Contributed by Roger Beeman <beeman@cisco.com>, with the help of
-   Mark Baushke <mdb@cisco.com> and the rest of the Gurus at CISCO.  */
-static time_t
-mktime_from_utc (struct tm *t)
-{
-  time_t tl, tb;
-
-  tl = mktime (t);
-  if (tl == -1)
-    return -1;
-  tb = mktime (gmtime (&tl));
-  return (tl <= tb ? (tl + (tl - tb)) : (tl - (tb - tl)));
-}
 
 /* The functions http_atotm and check_end are taken from wget */
 #define ISSPACE(c) is_ascii_space((c))
