@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Http.h,v 1.21.2.1 2000/06/08 10:13:31 lav Exp $ */
+/* $Id: Http.h,v 1.30 2000/08/03 22:55:57 lav Exp $ */
 
 #ifndef HTTP_H
 #define HTTP_H
@@ -33,6 +33,7 @@ class Http : public NetAccess
    {
       DISCONNECTED,
       CONNECTING,
+      CONNECTED,
       RECEIVING_HEADER,
       RECEIVING_BODY,
       DONE
@@ -42,11 +43,15 @@ class Http : public NetAccess
 
    void Init();
 
-   void	 Send(const char *format,...) PRINTF_LIKE(2,3);
+   void	Send(const char *format,...) PRINTF_LIKE(2,3);
 
-   FileOutputBuffer *send_buf;
-   FileInputBuffer *recv_buf;
+   IOBuffer *send_buf;
+   IOBuffer *recv_buf;
+   bool recv_buf_suspended;
    void SendMethod(const char *,const char *);
+   const char *last_method;
+   bool post;
+   char *post_data;
    void SendAuth();
    void SendBasicAuth(const char *tag,const char *u,const char *p);
    void SendRequest(const char *connection,const char *f);
@@ -57,9 +62,16 @@ class Http : public NetAccess
    void SendArrayInfoRequest();
    int status_code;
    void HandleHeaderLine(const char *name,const char *value);
+   void GetBetterConnection(int level,int count);
+   void SetCookie(const char *val);
+   char *MakeCookie(const char *host,const char *path);
+   void CookieMerge(char **c,const char *add);
+   bool CookieClosureMatch(const char *closure,const char *host,const char *path);
 
    int sock;
    void Disconnect();
+   void ResetRequestData();
+   void MoveConnectionHere(Http *o);
    int IsConnected()
       {
 	 if(sock==-1)
@@ -73,9 +85,8 @@ class Http : public NetAccess
    int   status_consumed;
    int proto_version;
    char *line;
-   long body_size;
-   long bytes_received;
-   char *location;
+   off_t body_size;
+   off_t bytes_received;
    bool sent_eot;
 
    bool ModeSupported();
@@ -87,7 +98,7 @@ class Http : public NetAccess
 
    bool chunked;
    long chunk_size;
-   long chunk_pos;
+   off_t chunk_pos;
 
    bool no_ranges;
    bool seen_ranges_bytes;
@@ -99,6 +110,7 @@ class Http : public NetAccess
 
 protected:
    bool hftp;  // ftp over http proxy.
+   bool https; // secure http
    bool use_head;
 
 public:
@@ -137,6 +149,9 @@ public:
    void UseCache(bool use) { no_cache_this=!use; }
 
    bool NeedSizeDateBeforehand() { return true; }
+
+   void Suspend();
+   void Resume();
 };
 
 class HFtp : public Http
@@ -155,4 +170,17 @@ public:
    virtual void Reconfig(const char *);
 };
 
+class Https : public Http
+{
+public:
+   Https();
+   Https(const Https *);
+   ~Https();
+
+   const char *GetProto() { return "https"; }
+
+   FileAccess *Clone() { return new Https(this); }
+   static FileAccess *New();
+};
+
 #endif//HTTP_H
