@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.cc,v 1.17 2000/07/19 07:24:15 lav Exp $ */
+/* $Id: Job.cc,v 1.18 2001/01/25 13:41:47 lav Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -514,7 +514,10 @@ void Job::ShowRunStatus(StatusLine *sl)
    if(waiting_num==1)
       waiting[0]->ShowRunStatus(sl);
    else
-      waiting[(time(0)/3)%waiting_num]->ShowRunStatus(sl);
+   {
+      waiting[(now/3)%waiting_num]->ShowRunStatus(sl);
+      current->TimeoutS(3);
+   }
 }
 
 Job *Job::FindAnyChild()
