@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.h,v 1.10 2000/03/24 18:53:24 lav Exp $ */
+/* $Id: Job.h,v 1.13 2000/07/19 07:24:15 lav Exp $ */
 
 #ifndef JOB_H
 #define JOB_H
@@ -36,8 +36,8 @@ class Job : public SMTask
    static void SortJobs();
 
    Job	 *next;
-
    static Job *chain;
+   int	 waiting_alloc;
 
 protected:
    bool fg;
@@ -48,7 +48,13 @@ protected:
 public:
    int	 jobno;
    Job	 *parent;
-   Job	 *waiting;
+
+   Job	 **waiting;
+   int	 waiting_num;
+
+   void AddWaiting(Job *);
+   void RemoveWaiting(Job *);
+   void ReplaceWaiting(Job *from,Job *to);
 
    void SetParent(Job *j) { parent=j; }
    void SetParentFg(Job *j, bool f=true)
@@ -77,6 +83,12 @@ public:
    void ListOneJobRecursively(int verbose,int indent);
    void ListDoneJobs();
    void BuryDoneJobs();
+   Job *FindAnyChild();
+   bool WaitsFor(Job *);
+   static Job *FindWhoWaitsFor(Job *);
+   int NumAwaitedJobs() { return waiting_num; }
+   Job *FindDoneAwaitedJob();
+   void WaitForAllChildren();
 
    static int NumberOfJobs();
    static Job *FindJob(int n);
