@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: MirrorJob.h,v 1.13 2000/04/15 18:57:30 lav Exp $ */
+/* $Id: MirrorJob.h,v 1.16 2000/09/07 18:38:36 lav Exp $ */
 
 #ifndef MIRRORJOB_H
 #define MIRRORJOB_H
@@ -85,6 +85,7 @@ class MirrorJob : public SessionJob
    int	 tot_files,new_files,mod_files,del_files;
    int	 dirs,del_dirs;
    int	 tot_symlinks,new_symlinks,mod_symlinks,del_symlinks;
+   int	 error_count;
 
    int	 flags;
 
@@ -114,8 +115,12 @@ class MirrorJob : public SessionJob
 
    bool remove_source_files;
 
+   int parallel;
+
    mode_t get_mode_mask();
 
+   int redirections;
+
 public:
    enum
    {
@@ -147,6 +152,7 @@ public:
    void	 ShowRunStatus(StatusLine *);
    void	 PrintStatus(int v);
    void	 SayFinal() { PrintStatus(-1); }
+   int	 ExitCode() { return error_count; }
 
    const char *SetInclude(const char *s)
       {
@@ -167,6 +173,8 @@ public:
 
    void  UseCache(bool u) { use_cache=u; }
    void	 RemoveSourceFiles() { remove_source_files=true; }
+
+   void  SetParallel(int p) { parallel=p; }
 };
 
 #endif//MIRRORJOB_H
