@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: NetAccess.h,v 1.17 2000/06/22 23:49:33 lav Exp $ */
+/* $Id: NetAccess.h,v 1.19 2001/02/13 16:50:22 lav Exp $ */
 
 #ifndef NETACCESS_H
 #define NETACCESS_H
@@ -79,7 +79,7 @@ protected:
    void SayConnectingTo();
 
    void SetProxy(const char *);
-   bool NoProxy();
+   static bool NoProxy(const char *);
 
    int Resolve(const char *defp,const char *ser,const char *pr);
 
@@ -132,7 +132,7 @@ private:
    BytesPool one;
 
 public:
-   RateLimit();
+   RateLimit(const char *closure);
    ~RateLimit();
 
    int BytesAllowed();
