@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.h,v 1.10 1999/09/18 23:41:13 lav Exp $ */
+/* $Id: Resolver.h,v 1.12 2000/01/27 17:07:53 lav Exp $ */
 
 #ifndef RESOLVER_H
 #define RESOLVER_H
@@ -54,7 +54,7 @@ class Resolver : public SMTask
 
    int pipe_to_child[2];
    ProcWait *w;
-   FileInputBuffer *buf;
+   Buffer *buf;
    int timeout;
 
    time_t start_time;
@@ -79,6 +79,10 @@ class Resolver : public SMTask
    static class ResolverCache *cache;
 
    bool no_cache;
+   bool use_fork;
+
+protected:
+   ~Resolver();
 
 public:
    int	 Do();
@@ -94,7 +98,6 @@ public:
 
    Resolver(const char *h,const char *p,const char *defp=0,const char *ser=0,
 	    const char *pr=0);
-   ~Resolver();
 
    void Reconfig(const char *name=0);
 
