@@ -18,12 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: SMTask.cc,v 1.8 1999/08/26 18:19:37 lav Exp $ */
+/* $Id: SMTask.cc,v 1.14 2000/02/29 14:16:01 lav Exp $ */
 
 #include <config.h>
 #include <assert.h>
 #include <sys/types.h>
 #include <sys/time.h>
+#include <stdio.h>
 #ifdef TIME_WITH_SYS_TIME
 # include <time.h>
 #endif
@@ -32,10 +33,14 @@
 
 SMTask	 *SMTask::chain=0;
 SMTask	 *SMTask::sched_scan=0;
+SMTask	 *SMTask::current=0;
 PollVec	 SMTask::sched_total;
 time_t	 SMTask::now=time(0);
 int	 SMTask::now_ms; // milliseconds
 
+static int task_count=0;
+static SMTaskInit init_task;
+
 SMTask::SMTask()
 {
    // insert in the chain
@@ -52,6 +57,11 @@ SMTask::SMTask()
    }
    suspended=false;
    running=false;
+   deleting=false;
+   task_count++;
+#ifdef TASK_DEBUG
+   printf("new SMTask %p (count=%d)\n",this,task_count);
+#endif
 }
 
 void  SMTask::Suspend() { suspended=true; }
@@ -59,6 +69,11 @@ void  SMTask::Resume()  { suspended=false; }
 
 SMTask::~SMTask()
 {
+#ifdef TASK_DEBUG
+   printf("delete SMTask %p (count=%d)\n",this,task_count);
+#endif
+   task_count--;
+   assert(!running);
    // remove from the chain
    SMTask **scan=&chain;
    while(*scan)
@@ -74,6 +89,17 @@ SMTask::~SMTask()
    }
 }
 
+void SMTask::Delete(SMTask *task)
+{
+   if(!task)
+      return;
+   if(task->deleting)
+      return;
+   task->deleting=true;
+   if(!task->running)
+      delete task;
+}
+
 void SMTask::UpdateNow()
 {
 #ifdef HAVE_GETTIMEOFDAY
@@ -86,9 +112,32 @@ void SMTask::UpdateNow()
 #endif
 }
 
+int SMTask::Roll(SMTask *task)
+{
+   int m=STALL;
+   if(task->running)
+      return m;
+   task->running=true;
+   while(!task->deleting && task->Do()==MOVED)
+      m=MOVED;
+   task->running=false;
+   return m;
+}
+
 void SMTask::Schedule()
 {
-   // get time onec and assume Do() don't take much time
+   SMTask *old_current=current;
+   assert(!current || current->running);
+
+   for(sched_scan=chain; sched_scan; sched_scan=sched_scan->next)
+   {
+      if(!sched_scan->running)
+	 sched_scan->block.Empty();
+   }
+
+   sched_total.Empty();
+
+   // get time once and assume Do() don't take much time
    UpdateNow();
 
    bool repeat=false;
@@ -100,23 +149,37 @@ void SMTask::Schedule()
 	 sched_scan=sched_scan->next;
 	 continue;
       }
-      sched_scan->block.Empty();
-      SMTask *tmp=sched_scan;
-      tmp->running=true;
-      int res=tmp->Do();
-      tmp->running=false;
-      if(sched_scan)
+      if(repeat)
+	 sched_scan->block.SetTimeout(0); // little optimization
+      int res=STALL;
+      current=sched_scan;
+      if(!current->deleting)
+      {
+	 current->running=true;
+	 res=current->Do();
+	 current->running=false;
+      }
+#if 0
+      if(res==MOVED)
+	 printf("MOVED: %p\n",current);
+      if(!repeat && current->block.GetTimeout()==0)
+	 printf("timeout==0: %p\n",current);
+#endif
+      if(sched_scan) // if the task called Schedule recursively, sched_scan==0.
 	 sched_scan=sched_scan->next;
-      if(res==WANTDIE)
-	 delete tmp;
-      else if(res==MOVED)
+      if(current->deleting)
+      {
+	 delete current;
+	 res=MOVED;
+      }
+      if(res==MOVED)
 	 repeat=true;
+      current=0;
    }
-   sched_total.Empty();
    if(repeat)
    {
-      sched_total+=NoWait();
-      return;
+      sched_total.SetTimeout(0);
+      goto out;
    }
 
    // now collect all wake up conditions; excluding suspended and
@@ -129,6 +192,8 @@ void SMTask::Schedule()
       && !sched_scan->running)
 	 sched_total.Merge(sched_scan->block);
    }
+out:
+   current=old_current;
    return;
 }
 
@@ -137,5 +202,20 @@ void SMTask::ReconfigAll(const char *name)
    UpdateNow();
    for(SMTask *scan=chain; scan; scan=scan->next)
       scan->Reconfig(name);
-   sched_total+=NoWait();  // for new values handling
+   sched_total.SetTimeout(0);  // for new values handling
+}
+
+int SMTaskInit::Do()
+{
+   return STALL;
+}
+SMTaskInit::SMTaskInit()
+{
+   running=true;
+   current=this;
+}
+SMTaskInit::~SMTaskInit()
+{
+   running=false;
+   current=0;
 }
