@@ -18,6 +18,8 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+/* $Id: bookmark.h,v 1.3 2000/11/14 12:16:58 lav Exp $ */
+
 #ifndef BOOKMARK_H
 #define BOOKMARK_H
 
@@ -33,7 +35,7 @@ class Bookmark : public KeyValueDB
    void Save();
    void Load();
    void Refresh();
-   void Lock(int type) { KeyValueDB::Lock(bm_fd,type); }
+   int Lock(int type) { return KeyValueDB::Lock(bm_fd,type); }
    void PreModify();
    void PostModify();
    void Close();
@@ -41,10 +43,16 @@ public:
    void Add(const char *id,const char *value);
    void Remove(const char *id);
    const char *Lookup(const char *id);
-   void List();
+   char *Format();
 
    Bookmark();
    ~Bookmark();
+
+   void Rewind()
+      {
+	 Refresh();
+	 KeyValueDB::Rewind();
+      }
 };
 
 #endif //BOOKMARK_H
