@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2001 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.122 2000/10/24 12:21:48 lav Exp $ */
+/* $Id: commands.cc,v 1.126 2001/02/13 10:07:31 lav Exp $ */
 
 #include <config.h>
 
@@ -350,6 +350,10 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 N_("Same as cat, but filter each file through zcat\n")},
    {"zmore",   cmd_cat,    N_("zmore <files>"),
 	 N_("Same as more, but filter each file through zcat\n")},
+   {"bzcat",    cmd_cat,    N_("bzcat <files>"),
+	 N_("Same as cat, but filter each file through bzcat\n")},
+   {"bzmore",   cmd_cat,    N_("bzmore <files>"),
+	 N_("Same as more, but filter each file through bzcat\n")},
 
    {NULL,NULL}
 };
@@ -598,6 +602,8 @@ Job *CmdExec::builtin_open()
          pass=strchr(optarg,',');
 	 if(pass==NULL)
 	    pass=strchr(optarg,' ');
+	 if(pass==NULL)
+	    pass=strchr(optarg,':');
 	 if(pass==NULL)
    	    break;
 	 *pass=0;
@@ -1233,6 +1239,10 @@ CMD(mkdir)
    return j;
 }
 
+#ifndef O_ASCII
+# define O_ASCII 0
+#endif
+
 CMD(source)
 {
    if(args->count()<2)
@@ -1241,7 +1251,7 @@ CMD(source)
       eprintf(_("Usage: %s <file>\n"),args->a0());
       return 0;
    }
-   parent->SetCmdFeeder(new FileFeeder(new FileStream(args->getarg(1),O_RDONLY)));
+   parent->SetCmdFeeder(new FileFeeder(new FileStream(args->getarg(1),O_RDONLY|O_ASCII)));
    exit_code=0;
    return 0;
 }
@@ -1863,7 +1873,7 @@ CMD(help)
 CMD(ver)
 {
    printf(
-      _("Lftp | Version %s | Copyright (c) 1996-2000 Alexander V. Lukyanov\n"),VERSION);
+      _("Lftp | Version %s | Copyright (c) 1996-2001 Alexander V. Lukyanov\n"),VERSION);
    printf(
       _("This is free software with ABSOLUTELY NO WARRANTY. See COPYING for details.\n"));
    printf(
