@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: history.cc,v 1.7 2000/05/04 17:49:16 lav Exp $ */
+/* $Id: history.cc,v 1.9 2000/11/14 12:16:58 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -37,6 +37,7 @@ History::History()
    full=0;
    stamp=0;
    fd=-1;
+   modified=false;
 
    const char *home=getenv("HOME");
    if(home==0)
@@ -117,8 +118,9 @@ void History::Load()
       fd=open(file,O_RDONLY);
       if(fd==-1)
 	 return;
-      Lock(fd,F_RDLCK);
       fcntl(fd,F_SETFD,FD_CLOEXEC);
+      if(Lock(fd,F_RDLCK)==-1)
+	 fprintf(stderr,"%s: lock for reading failed, trying to read anyway\n",file);
    }
    if(!full)
       full=new KeyValueDB;
@@ -147,16 +149,24 @@ void History::Set(FileAccess *s,const char *cwd)
    sprintf(res,"%lu:",(unsigned long)time(0));
    url::encode_string(cwd,res+strlen(res),URL_PATH_UNSAFE);
    super::Add(s->GetConnectURL(s->NO_PATH|s->NO_PASSWORD),res);
+   modified=true;
 }
 
 void History::Save()
 {
    Close();
+   if(!modified)
+      return;
    fd=open(file,O_RDWR|O_CREAT,0600);
    if(fd==-1)
       return;
-   Lock(fd,F_WRLCK);
    fcntl(fd,F_SETFD,FD_CLOEXEC);
+   if(Lock(fd,F_WRLCK)==-1)
+   {
+      fprintf(stderr,"%s: lock for writing failed\n",file);
+      Close();
+      return;
+   }
    Refresh();
 
    // merge
