@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: misc.cc,v 1.22 2000/06/09 00:17:58 lav Exp $ */
+/* $Id: misc.cc,v 1.24 2001/02/13 10:07:31 lav Exp $ */
 
 #include <config.h>
 #include "xmalloc.h"
@@ -276,7 +276,8 @@ int parse_perms(const char *s)
 {
    int p=0;
 
-   if(strlen(s)!=9)
+   if(strlen(s)!=9
+   && !(strlen(s)==10 && s[9]=='+'))   // ACL tag
       bad: return -1;
 
    switch(s[0])
@@ -435,3 +436,20 @@ const char *squeeze_file_name(const char *name,int w)
    sprintf(buf,"...%s",b+3);
    return buf;
 }
+
+/* Converts struct tm to time_t, assuming the data in tm is UTC rather
+   than local timezone (mktime assumes the latter).
+
+   Contributed by Roger Beeman <beeman@cisco.com>, with the help of
+   Mark Baushke <mdb@cisco.com> and the rest of the Gurus at CISCO.  */
+time_t
+mktime_from_utc (struct tm *t)
+{
+  time_t tl, tb;
+
+  tl = mktime (t);
+  if (tl == -1)
+    return -1;
+  tb = mktime (gmtime (&tl));
+  return (tl <= tb ? (tl + (tl - tb)) : (tl - (tb - tl)));
+}
