@@ -1,7 +1,7 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: netrc.cc,v 1.4 1999/05/20 10:05:24 lav Exp $ */
+/* $Id: netrc.cc,v 1.7 2000/02/12 17:45:41 lav Exp $ */
 
 #include <config.h>
 
@@ -39,10 +39,10 @@ NetRC::Entry::Entry(const char *h,const char *u,const char *p,const char *a)
 
 NetRC::Entry::~Entry()
 {
-   free(host);
-   free(user);
-   free(pass);
-   free(acct);
+   xfree(host);
+   xfree(user);
+   xfree(pass);
+   xfree(acct);
 }
 
 static bool comment(const char *s, FILE *f)
@@ -67,7 +67,8 @@ NetRC::Entry *NetRC::LookupHost(const char *h)
    char cpass[256]="";
    char cacct[256]="";
    const char *home=getenv("HOME");
-   if(!home) home=".";
+   if(!home)
+      return 0;
    char *netrc=(char*)alloca(strlen(home)+8);
    sprintf(netrc,"%s/.netrc",home);
    FILE *f=fopen(netrc,"r");
