@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: rmJob.cc,v 1.5 2000/01/22 16:27:31 lav Exp $ */
+/* $Id: rmJob.cc,v 1.6 2000/08/25 23:19:28 lav Exp $ */
 
 #include <config.h>
 
@@ -41,9 +41,11 @@ void  rmJob::SayFinal()
    else if(failed)
    {
       if(mode==FA::REMOVE_DIR)
-	 printf(_("%s failed for %d of %d directories\n"),op,failed,file_count);
+	 printf(plural("%s failed for %d of %d director$y|ies$\n",file_count),
+	    op,failed,file_count);
       else
-	 printf(_("%s failed for %d of %d files\n"),op,failed,file_count);
+	 printf(plural("%s failed for %d of %d file$|s$\n",file_count),
+	    op,failed,file_count);
    }
    else
    {
